@@ -1,9 +1,6 @@
 package MooseX::Storage::Basic;
-BEGIN {
-  $MooseX::Storage::Basic::AUTHORITY = 'cpan:STEVAN';
-}
 # ABSTRACT: The simplest level of serialization
-$MooseX::Storage::Basic::VERSION = '0.46';
+$MooseX::Storage::Basic::VERSION = '0.47';
 use Moose::Role;
 use MooseX::Storage::Engine;
 use String::RewritePrefix;
@@ -67,19 +64,13 @@ __END__
 
 =encoding UTF-8
 
-=for :stopwords Chris Prather Stevan Little יובל קוג'מן (Yuval Kogman) Infinity
-Interactive, Inc. Golden Steinbrunner Florian Ragwitz Johannes Plunien
-Jonathan Rockway Yu Jos Boumans Karen Etheridge Ricardo Signes Robert Boone
-Shawn M Moore Cory Tomas Doran Yuval Kogman Watson Dagfinn Ilmari Mannsåker
-Dan Brook David
-
 =head1 NAME
 
 MooseX::Storage::Basic - The simplest level of serialization
 
 =head1 VERSION
 
-version 0.46
+version 0.47
 
 =head1 SYNOPSIS
 
