@@ -1,9 +1,6 @@
 package MooseX::Storage::Deferred;
-BEGIN {
-  $MooseX::Storage::Deferred::AUTHORITY = 'cpan:STEVAN';
-}
 # ABSTRACT: A role for indecisive programmers
-$MooseX::Storage::Deferred::VERSION = '0.46';
+$MooseX::Storage::Deferred::VERSION = '0.47';
 use Moose::Role;
 with 'MooseX::Storage::Basic';
 use Carp 'confess';
@@ -70,19 +67,13 @@ __END__
 
 =encoding UTF-8
 
-=for :stopwords Chris Prather Stevan Little יובל קוג'מן (Yuval Kogman) Infinity
-Interactive, Inc. Golden Steinbrunner Florian Ragwitz Johannes Plunien
-Jonathan Rockway Yu Jos Boumans Karen Etheridge Ricardo Signes Robert Boone
-Shawn M Moore Cory Tomas Doran Yuval Kogman Watson Dagfinn Ilmari Mannsåker
-Dan Brook David JSONpm
-
 =head1 NAME
 
 MooseX::Storage::Deferred - A role for indecisive programmers
 
 =head1 VERSION
 
-version 0.46
+version 0.47
 
 =head1 SYNOPSIS
 
@@ -130,6 +121,8 @@ SYNOPSIS for more info)
 
 =item I<JSON>
 
+=for stopwords JSONpm
+
 =item I<JSONpm>
 
 =item I<YAML>
