@@ -1,13 +1,8 @@
 package MooseX::Storage::Engine::Trait::DisableCycleDetection;
-{
-  $MooseX::Storage::Engine::Trait::DisableCycleDetection::VERSION = '0.44';
-}
-BEGIN {
-  $MooseX::Storage::Engine::Trait::DisableCycleDetection::AUTHORITY = 'cpan:STEVAN';
-}
 # ABSTRACT: A custom trait to bypass cycle detection
-
+$MooseX::Storage::Engine::Trait::DisableCycleDetection::VERSION = '0.47';
 use Moose::Role;
+use namespace::autoclean;
 
 around 'check_for_cycle_in_collapse' => sub {
     my ($orig, $self, $attr, $value) = @_;
@@ -23,18 +18,13 @@ __END__
 
 =encoding UTF-8
 
-=for :stopwords Chris Prather Stevan Little יובל קוג'מן (Yuval Kogman) Infinity
-Interactive, Inc. Plunien Jonathan Rockway Yu Jos Boumans Karen Etheridge
-Ricardo SIGNES Signes Robert Boone Shawn M Moore Tomas Doran (t0m) Yuval
-Cory Kogman t0m Watson Dagfinn Ilmari Mannsåker Florian Ragwitz Johannes
-
 =head1 NAME
 
 MooseX::Storage::Engine::Trait::DisableCycleDetection - A custom trait to bypass cycle detection
 
 =head1 VERSION
 
-version 0.44
+version 0.47
 
 =head1 SYNOPSIS
 
