@@ -1,16 +1,9 @@
 package MooseX::Storage::Format::JSON;
-{
-  $MooseX::Storage::Format::JSON::VERSION = '0.44';
-}
-BEGIN {
-  $MooseX::Storage::Format::JSON::AUTHORITY = 'cpan:STEVAN';
-}
 # ABSTRACT: A JSON serialization role
+$MooseX::Storage::Format::JSON::VERSION = '0.47';
 use Moose::Role;
-
-no warnings 'once';
-
 use JSON::Any;
+use namespace::autoclean;
 
 requires 'pack';
 requires 'unpack';
@@ -38,18 +31,13 @@ __END__
 
 =encoding UTF-8
 
-=for :stopwords Chris Prather Stevan Little יובל קוג'מן (Yuval Kogman) Infinity
-Interactive, Inc. Plunien Jonathan Rockway Yu Jos Boumans Karen Etheridge
-Ricardo SIGNES Signes Robert Boone Shawn M Moore Tomas Doran (t0m) Yuval
-Cory Kogman t0m Watson Dagfinn Ilmari Mannsåker Florian Ragwitz Johannes
-
 =head1 NAME
 
 MooseX::Storage::Format::JSON - A JSON serialization role
 
 =head1 VERSION
 
-version 0.44
+version 0.47
 
 =head1 SYNOPSIS
 
