@@ -1,9 +1,6 @@
 package MooseX::Storage::IO::File;
-BEGIN {
-  $MooseX::Storage::IO::File::AUTHORITY = 'cpan:STEVAN';
-}
 # ABSTRACT: A basic File I/O role
-$MooseX::Storage::IO::File::VERSION = '0.46';
+$MooseX::Storage::IO::File::VERSION = '0.47';
 use Moose::Role;
 use MooseX::Storage::Engine::IO::File;
 use namespace::autoclean;
@@ -31,19 +28,13 @@ __END__
 
 =encoding UTF-8
 
-=for :stopwords Chris Prather Stevan Little יובל קוג'מן (Yuval Kogman) Infinity
-Interactive, Inc. Golden Steinbrunner Florian Ragwitz Johannes Plunien
-Jonathan Rockway Yu Jos Boumans Karen Etheridge Ricardo Signes Robert Boone
-Shawn M Moore Cory Tomas Doran Yuval Kogman Watson Dagfinn Ilmari Mannsåker
-Dan Brook David
-
 =head1 NAME
 
 MooseX::Storage::IO::File - A basic File I/O role
 
 =head1 VERSION
 
-version 0.46
+version 0.47
 
 =head1 SYNOPSIS
 
