@@ -1,25 +1,14 @@
 package MooseX::Storage::Meta::Attribute::DoNotSerialize;
-{
-  $MooseX::Storage::Meta::Attribute::DoNotSerialize::VERSION = '0.44';
-}
-BEGIN {
-  $MooseX::Storage::Meta::Attribute::DoNotSerialize::AUTHORITY = 'cpan:STEVAN';
-}
 # ABSTRACT: A custom meta-attribute to bypass serialization
+$MooseX::Storage::Meta::Attribute::DoNotSerialize::VERSION = '0.47';
 use Moose;
-
+use namespace::autoclean;
 extends 'Moose::Meta::Attribute';
    with 'MooseX::Storage::Meta::Attribute::Trait::DoNotSerialize';
 
 # register this alias ...
 package Moose::Meta::Attribute::Custom::DoNotSerialize;
-{
-  $Moose::Meta::Attribute::Custom::DoNotSerialize::VERSION = '0.44';
-}
-BEGIN {
-  $Moose::Meta::Attribute::Custom::DoNotSerialize::AUTHORITY = 'cpan:STEVAN';
-}
-
+$Moose::Meta::Attribute::Custom::DoNotSerialize::VERSION = '0.47';
 sub register_implementation { 'MooseX::Storage::Meta::Attribute::DoNotSerialize' }
 
 1;
@@ -30,16 +19,13 @@ __END__
 
 =encoding UTF-8
 
-=for :stopwords Chris Prather Stevan Little יובל קוג'מן (Yuval Kogman) Infinity
-Interactive, Inc. culted
-
 =head1 NAME
 
 MooseX::Storage::Meta::Attribute::DoNotSerialize - A custom meta-attribute to bypass serialization
 
 =head1 VERSION
 
-version 0.44
+version 0.47
 
 =head1 SYNOPSIS
 
@@ -62,6 +48,8 @@ version 0.44
 
 =head1 DESCRIPTION
 
+=for stopwords culted
+
 Sometimes you don't want a particular attribute to be part of the
 serialization, in this case, you want to make sure that attribute
 uses this custom meta-attribute. See the SYNOPSIS for a nice example
