@@ -1,23 +1,12 @@
 package MooseX::Storage::Meta::Attribute::Trait::DoNotSerialize;
-{
-  $MooseX::Storage::Meta::Attribute::Trait::DoNotSerialize::VERSION = '0.44';
-}
-BEGIN {
-  $MooseX::Storage::Meta::Attribute::Trait::DoNotSerialize::AUTHORITY = 'cpan:STEVAN';
-}
 # ABSTRACT: A custom meta-attribute-trait to bypass serialization
-
+$MooseX::Storage::Meta::Attribute::Trait::DoNotSerialize::VERSION = '0.47';
 use Moose::Role;
+use namespace::autoclean;
 
 # register this alias ...
 package Moose::Meta::Attribute::Custom::Trait::DoNotSerialize;
-{
-  $Moose::Meta::Attribute::Custom::Trait::DoNotSerialize::VERSION = '0.44';
-}
-BEGIN {
-  $Moose::Meta::Attribute::Custom::Trait::DoNotSerialize::AUTHORITY = 'cpan:STEVAN';
-}
-
+$Moose::Meta::Attribute::Custom::Trait::DoNotSerialize::VERSION = '0.47';
 sub register_implementation { 'MooseX::Storage::Meta::Attribute::Trait::DoNotSerialize' }
 
 1;
@@ -28,16 +17,13 @@ __END__
 
 =encoding UTF-8
 
-=for :stopwords Chris Prather Stevan Little יובל קוג'מן (Yuval Kogman) Infinity
-Interactive, Inc. culted
-
 =head1 NAME
 
 MooseX::Storage::Meta::Attribute::Trait::DoNotSerialize - A custom meta-attribute-trait to bypass serialization
 
 =head1 VERSION
 
-version 0.44
+version 0.47
 
 =head1 SYNOPSIS
 
@@ -60,6 +46,8 @@ version 0.44
 
 =head1 DESCRIPTION
 
+=for stopwords culted
+
 Sometimes you don't want a particular attribute to be part of the
 serialization, in this case, you want to make sure that attribute
 uses this custom meta-attribute-trait. See the SYNOPSIS for a nice
